@@ -18,13 +18,14 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 #include "linkchecker.h"
-#include "linkstatus.h"
 #include "searchmanager.h"
 #include "../utils/utils.h"
 #include "../parser/htmlparser.h"
 
 #include <qstring.h>
 #include <qtimer.h>
+#include <qtextcodec.h> 
+#include <qcstring.h>
 
 #include <kio/netaccess.h>
 #include <kio/global.h>
@@ -45,13 +46,14 @@ int LinkChecker::count_ = 0;
 LinkChecker::LinkChecker(LinkStatus* linkstatus, int time_out,
                          QObject *parent, const char *name)
         : QObject(parent, name), search_manager_(0), 
-        linkstatus_(linkstatus), t_job_(0), time_out_(time_out), checker_(0),
-        redirection_(false), header_checked_(false), finnished_(false), parsing_(false)
+        linkstatus_(linkstatus), t_job_(0), time_out_(time_out), checker_(0), document_charset_(), 
+        redirection_(false), header_checked_(false), finnished_(false), 
+        parsing_(false), is_charset_checked_(false), has_defined_charset_(false)
 {
     Q_ASSERT(linkstatus_);
     Q_ASSERT(!linkstatus_->checked());
 
-    kdDebug(23100) << ++count_ << ": " << "Checking " << linkstatus_->absoluteUrl().url() << endl;
+    kdDebug(23100) << endl << ++count_ << ": " << "Checking " << linkstatus_->absoluteUrl().url() << endl;
 }
 
 LinkChecker::~LinkChecker()
@@ -67,7 +69,7 @@ void LinkChecker::check()
 {
     Q_ASSERT(!finnished_);
 
-    KURL url = linkStatus()->absoluteUrl();
+    KURL url(linkStatus()->absoluteUrl());
     Q_ASSERT(url.isValid());
 
     if(url.hasRef())
@@ -77,16 +79,24 @@ void LinkChecker::check()
         t_job_ = KIO::get
                      (url, false, false);
 
-        t_job_->addMetaData("PropagateHttpHeader", "true"); // to see the http header
-
+        t_job_->addMetaData("PropagateHttpHeader", "true"); // to have the http header
+        if(search_manager_->sendIdentification())
+        {
+            t_job_->addMetaData("SendUserAgent", "true");
+            t_job_->addMetaData("UserAgent", search_manager_->userAgent());
+        }
+        else
+            t_job_->addMetaData("SendUserAgent", "false");
+        
+        
         QObject::connect(t_job_, SIGNAL(data(KIO::Job *, const QByteArray &)),
                          this, SLOT(slotData(KIO::Job *, const QByteArray &)));
         QObject::connect(t_job_, SIGNAL(mimetype(KIO::Job *, const QString &)),
                          this, SLOT(slotMimetype(KIO::Job *, const QString &)));
         QObject::connect(t_job_, SIGNAL(result(KIO::Job *)),
                          this, SLOT(slotResult(KIO::Job *)));
-        QObject::connect(t_job_, SIGNAL(permanentRedirection(KIO::Job *, const KURL &, const KURL &)),
-                         this, SLOT(slotPermanentRedirection(KIO::Job *, const KURL &, const KURL &)));
+        QObject::connect(t_job_, SIGNAL(redirection(KIO::Job *, const KURL &)),
+                         this, SLOT(slotRedirection(KIO::Job *, const KURL &)));
 
         QTimer::singleShot( time_out_ * 1000, this, SLOT(slotTimeOut()) );
     }
@@ -103,7 +113,9 @@ void LinkChecker::slotTimeOut()
         if(t_job_->error() != KIO::ERR_USER_CANCELED)
         {
             linkstatus_->setErrorOccurred(true);
-            linkstatus_->setError(i18n( "Timeout" ));
+            linkstatus_->setChecked(true);
+            linkstatus_->setError(i18n("Timeout"));
+            linkstatus_->setStatus(LinkStatus::TIMEOUT);
 
             killJob();
             finnish();
@@ -116,15 +128,15 @@ void LinkChecker::slotMimetype (KIO::Job* /*job*/, const QString &type)
     if(finnished_)
         return;
 
-    kdDebug(23100) <<  "LinkChecker::slotMimetype:" << type << "-> " << linkstatus_->absoluteUrl().url() 
-            << " - " << t_job_->slave() << "/" <<  t_job_->slave()->slave_pid() << endl;
+//     kdDebug(23100) <<  "LinkChecker::slotMimetype:" << type << "-> " << linkstatus_->absoluteUrl().url() 
+//             << " - " << t_job_->slave() << "/" <<  t_job_->slave()->slave_pid() << endl;
 
     Q_ASSERT(t_job_);
 
     LinkStatus* ls = 0;
-    if(redirection_)
+/*    if(redirection_)
         ls = linkStatus()->redirection();
-    else
+    else*/
         ls = linkstatus_;
     Q_ASSERT(ls);
 
@@ -140,9 +152,10 @@ void LinkChecker::slotMimetype (KIO::Job* /*job*/, const QString &type)
             //kdDebug(23100) <<  "only check header: " << ls->absoluteUrl().prettyURL() << endl;
 
             // file is OK (http can have an error page though job->error() is false)
-            if(url.protocol() != "http" && url.protocol() != "https")
+            if(!url.protocol().startsWith("http"))
             {
-                ls->setStatus("OK");
+                ls->setStatusText("OK");
+                ls->setStatus(LinkStatus::SUCCESSFULL);
                 
                 killJob();                
                 finnish();
@@ -153,13 +166,14 @@ void LinkChecker::slotMimetype (KIO::Job* /*job*/, const QString &type)
             //kdDebug(23100) <<  "NOT only check header: " << ls->absoluteUrl().prettyURL() << endl;
 
             // file is OK (http can have an error page though job->error() is false)
-            if(url.protocol() != "http" && url.protocol() != "https") // if not, it have to go trough slotData to get the http header
+            if(!url.protocol().startsWith("http")) // if not, it have to go trough slotData to get the http header
             {
                 // it's not an html page, so we don't want the file content
                 if(type != "text/html"/* && type != "text/plain"*/)
                 {
                     //kdDebug(23100) <<  "mimetype: " << type << endl;
-                    ls->setStatus("OK");
+                    ls->setStatusText("OK");
+                    ls->setStatus(LinkStatus::SUCCESSFULL);
                     
                     killJob();                    
                     finnish();
@@ -170,19 +184,19 @@ void LinkChecker::slotMimetype (KIO::Job* /*job*/, const QString &type)
 }
 
 void LinkChecker::slotData(KIO::Job* /*job*/, const QByteArray& data)
-{
+{   
     if(finnished_)
         return;
 
     kdDebug(23100) <<  "LinkChecker::slotData -> " << linkstatus_->absoluteUrl().url() 
             << " - " << t_job_->slave() << "/" <<  t_job_->slave()->slave_pid()  << endl;
-
+    
     Q_ASSERT(t_job_);
-
+    
     LinkStatus* ls = 0;
-    if(redirection_)
+/*    if(redirection_)
         ls = linkStatus()->redirection();
-    else
+    else*/
         ls = linkstatus_;
     Q_ASSERT(ls);
 
@@ -193,11 +207,11 @@ void LinkChecker::slotData(KIO::Job* /*job*/, const QByteArray& data)
         if(ls->onlyCheckHeader())
         {
             Q_ASSERT(header_checked_ == false);
-            // the job should had been killed in slotMimetype
+            // the job should have been killed in slotMimetype
             Q_ASSERT(url.protocol() == "http" || url.protocol() == "https");
 
             // get the header and quit
-            if(url.protocol() == "http" || url.protocol() == "https")
+            if(url.protocol().startsWith("http"))
             {
                 // get the header
                 ls->setHttpHeader(getHttpHeader(t_job_));
@@ -207,45 +221,75 @@ void LinkChecker::slotData(KIO::Job* /*job*/, const QByteArray& data)
 
                 if(header_checked_)
                 {
-                    killJob();                    
+                    killJob();
+                    linkstatus_->setStatus(getHttpStatus());
+                    linkstatus_->setChecked(true);
                     finnish();
+                    return;
                 }
             }
         }
         else
         {
-            if(url.protocol() == "http" || url.protocol() == "https")
+            if(url.protocol().startsWith("http"))
             {
                 if(!header_checked_)
                 {
-                    ls->setHttpHeader(getHttpHeader(t_job_));
+                    ls->setHttpHeader(getHttpHeader(t_job_));                    
                 }
                 if(ls->mimeType() != "text/html" && header_checked_)
                 {
                     //kdDebug(23100) <<  "mimetype of " << ls->absoluteUrl().prettyURL() << ": " << ls->mimeType() << endl;
+                    ls->setStatus(getHttpStatus());
                     killJob();
                     finnish(); // if finnish is called before kill what you get is a segfault, don't know why
+                    return;
                 }
                 else if(t_job_->isErrorPage() && header_checked_)
                 {
                     //kdDebug(23100) <<  "ERROR PAGE" << endl;
                     ls->setIsErrorPage(true);
+                    ls->setStatus(getHttpStatus());
                     killJob();
                     finnish();
+                    return;
                 }
-                else
-                    doc_html_ += QString(data);
             }
-
             else
             {
                 Q_ASSERT(ls->mimeType() == "text/html");
-                doc_html_ += QString(data);
             }
+            if(!is_charset_checked_) 
+                findDocumentCharset(data);
+            
+            QTextCodec* codec = 0;
+            if(has_defined_charset_) 
+                codec = QTextCodec::codecForName(document_charset_);
+            if(!codec)
+                codec = QTextCodec::codecForName("iso8859-1"); // default
+            
+            doc_html_ += codec->toUnicode(data);
         }
     }
 }
 
+void LinkChecker::findDocumentCharset(QString const& doc)
+{
+    Q_ASSERT(!is_charset_checked_);
+    
+    is_charset_checked_ = true; // only check the first stream of data
+                    
+    if(header_checked_)
+        document_charset_ = linkstatus_->httpHeader().charset();
+
+    // try to look in the meta elements                    
+    if(document_charset_.isNull() || document_charset_.isEmpty()) 
+        document_charset_ = HtmlParser::findCharsetInMetaElement(doc);
+    
+    if(!document_charset_.isNull() && !document_charset_.isEmpty())
+        has_defined_charset_ = true;
+}
+
 // only comes here if an error happened or in case of a clean html page
 // if onlyCheckHeader is false
 void LinkChecker::slotResult(KIO::Job* /*job*/)
@@ -256,7 +300,18 @@ void LinkChecker::slotResult(KIO::Job* /*job*/)
     kdDebug(23100) <<  "LinkChecker::slotResult -> " << linkstatus_->absoluteUrl().url()  << endl;
 
     Q_ASSERT(t_job_);
-
+    if(!t_job_)
+        return;
+    
+    if(redirection_) {
+        if(!processRedirection(redirection_url_)) {
+            t_job_ = 0;
+            linkstatus_->setChecked(true);
+            finnish();
+            return;
+        }
+    }
+            
     KIO::TransferJob* job = t_job_;
     t_job_ = 0;
 
@@ -295,15 +350,17 @@ void LinkChecker::slotResult(KIO::Job* /*job*/)
 
         if(job->error() == KIO::ERR_IS_DIRECTORY)
         {
-            ls->setStatus("OK");
+            ls->setStatusText("OK");
+            ls->setStatus(LinkStatus::SUCCESSFULL);
         }
         else
         {
             ls->setErrorOccurred(true);
+            ls->setStatus(LinkStatus::BROKEN);
 
             if(job->errorString().isEmpty())
                 kdWarning(23100) << "\n\nError string is empty, error = " << job->error() << "\n\n\n";
-            if(job->error() != KIO::ERR_NO_CONTENT)
+            if(job->error() != KIO::ERR_NO_CONTENT) 
                 ls->setError(job->errorString());
             else
                 ls->setError(i18n( "No Content") );
@@ -312,9 +369,10 @@ void LinkChecker::slotResult(KIO::Job* /*job*/)
 
     else
     {
-        if(ls->absoluteUrl().protocol() != "http" &&
-           ls->absoluteUrl().protocol() != "https")
-            ls->setStatus("OK");
+        if(!ls->absoluteUrl().protocol().startsWith("http")) {
+            ls->setStatusText("OK");
+            ls->setStatus(LinkStatus::SUCCESSFULL);
+           }
         else
         {
             if(!header_checked_)
@@ -325,6 +383,8 @@ void LinkChecker::slotResult(KIO::Job* /*job*/)
                 return;
             }
             Q_ASSERT(header_checked_);
+            
+            ls->setStatus(getHttpStatus());
         }
 
         if(!doc_html_.isNull() && !doc_html_.isEmpty())
@@ -338,6 +398,7 @@ void LinkChecker::slotResult(KIO::Job* /*job*/)
                 ls->setBaseURI(KURL(parser.baseUrl().url()));
             if(parser.hasTitle())
                 ls->setHtmlDocTitle(parser.title().attributeTITLE());
+            
             ls->setChildrenNodes(parser.nodes());
             parsing_ = false;
         }
@@ -345,39 +406,44 @@ void LinkChecker::slotResult(KIO::Job* /*job*/)
     finnish();
 }
 
-/*
-void LinkChecker::slotRedirection (KIO::Job* job, const KURL &url)
-{}
-*/
 
-void LinkChecker::slotPermanentRedirection (KIO::Job* /*job*/, const KURL &fromUrl, const KURL &toUrl)
+void LinkChecker::slotRedirection (KIO::Job* /*job*/, const KURL &url)
+{
+    kdDebug(23100) <<  "LinkChecker::slotRedirection -> " << 
+            linkstatus_->absoluteUrl().url()  << " -> " << url.url() << endl;
+//             << " - " << t_job_->slave() << "/" <<  t_job_->slave()->slave_pid() << endl;
+    
+    redirection_ = true;
+    redirection_url_ = url;
+}
+
+bool LinkChecker::processRedirection(KURL const& toUrl)
 {
     if(finnished_)
-        return;
+        return true;
 
-    kdDebug(23100) <<  "LinkChecker::slotPermanentRedirection -> " << linkstatus_->absoluteUrl().url() 
-            << " - " << t_job_->slave() << "/" <<  t_job_->slave()->slave_pid() << endl;
+    kdDebug(23100) <<  "LinkChecker::processRedirection -> " << linkstatus_->absoluteUrl().url() << " -> " << toUrl.url() << endl;
 
     Q_ASSERT(t_job_);
-    Q_ASSERT(linkstatus_->absoluteUrl().protocol() == "http" ||
-             linkstatus_->absoluteUrl().protocol() == "https");
-
-    redirection_ = true;
+    Q_ASSERT(linkstatus_->absoluteUrl().protocol().startsWith("http"));
+    Q_ASSERT(redirection_);
 
     linkstatus_->setHttpHeader(getHttpHeader(t_job_, false));
     linkstatus_->setIsRedirection(true);
-    linkstatus_->setStatus("redirection");
+    linkstatus_->setStatusText("redirection");
+    linkstatus_->setStatus(LinkStatus::HTTP_REDIRECTION);
     linkstatus_->setChecked(true);
-
-    LinkStatus* ls_red = new LinkStatus(toUrl);
+    
+    LinkStatus* ls_red = new LinkStatus(*linkstatus_);
+    ls_red->setAbsoluteUrl(toUrl);
     ls_red->setRootUrl(linkstatus_->rootUrl());
 
     if(!linkstatus_->onlyCheckHeader())
         ls_red->setOnlyCheckHeader(false);
 
     linkstatus_->setRedirection(ls_red);
-    linkstatus_->redirection()->setParent(linkstatus_);
-    linkstatus_->redirection()->setOriginalUrl(toUrl.url());
+    ls_red->setParent(linkstatus_);
+    ls_red->setOriginalUrl(toUrl.url());
 
     Q_ASSERT(search_manager_);
 
@@ -391,15 +457,16 @@ void LinkChecker::slotPermanentRedirection (KIO::Job* /*job*/, const KURL &fromU
             ls_red->setExternalDomainDepth(linkstatus_->externalDomainDepth());
     }
 
-    if(!toUrl.isValid() || search_manager_->existUrl(toUrl, fromUrl))
+    if(!toUrl.isValid() || search_manager_->existUrl(toUrl, linkstatus_->absoluteUrl()))
     {
-        linkStatus()->redirection()->setChecked(false);
-        //t_job_->kill(true); // causes the terrible segfault bug
-        t_job_ = 0;
-        finnish();
+        ls_red->setChecked(false);
+        return false;
     }
     else
-        linkStatus()->redirection()->setChecked(true);
+    {
+        ls_red->setChecked(true);
+        return true;
+    }
 }
 
 void LinkChecker::finnish()
@@ -424,17 +491,21 @@ void LinkChecker::finnish()
 HttpResponseHeader LinkChecker::getHttpHeader(KIO::Job* /*job*/, bool remember_check)
 {
     //kdDebug(23100) <<  "LinkChecker::getHttpHeader -> " << linkstatus_->absoluteUrl().url() << endl;
-
+    
     Q_ASSERT(!finnished_);
     Q_ASSERT(t_job_);
 
     QString header_string = t_job_->queryMetaData("HTTP-Headers");
     //    Q_ASSERT(!header_string.isNull() && !header_string.isEmpty());
-    //kdDebug(23100) <<  header_string << endl;
+//     kdDebug(23100) << "HTTP header: " << endl << header_string << endl;
+//     kdDebug(23100) << "Keys: " << HttpResponseHeader(header_string).keys() << endl;
+//     kdDebug(23100) << "Content-type: " << HttpResponseHeader(header_string).contentType() << endl;
+//     kdDebug(23100) << "Content-type: " << HttpResponseHeader(header_string).value("content-type") << endl;
+
     if(header_string.isNull() || header_string.isEmpty())
     {
         header_checked_ = false;
-        kdDebug(23100) <<  "header_string.isNull() || header_string.isEmpty(): "
+        kdWarning(23100) <<  "header_string.isNull() || header_string.isEmpty(): "
         << linkstatus_->toString()  << endl;
     }
     else if(remember_check)
@@ -447,6 +518,15 @@ void LinkChecker::checkRef()
 {
     KURL url(linkStatus()->absoluteUrl());
     Q_ASSERT(url.hasRef());
+    
+    QString ref = url.ref();
+    if(ref == "" || ref == "top") {
+        linkstatus_->setStatusText("OK");
+        linkstatus_->setStatus(LinkStatus::SUCCESSFULL);
+        finnish();
+        return;
+    }
+
     QString url_base;
     LinkStatus const* ls_parent = 0;
     int i_ref = -1;
@@ -477,7 +557,7 @@ void LinkChecker::checkRef()
 void LinkChecker::checkRef(KURL const& url)
 {
     Q_ASSERT(search_manager_);
-
+    
     QString url_string = url.url();
     KHTMLPart* html_part = search_manager_->htmlPart(url_string);
     if(!html_part)
@@ -507,12 +587,14 @@ void LinkChecker::checkRef(KURL const& url)
 
     if(hasAnchor(html_part, linkStatus()->absoluteUrl().ref()))
     {
-        linkstatus_->setStatus("OK");
+        linkstatus_->setStatusText("OK");
+        linkstatus_->setStatus(LinkStatus::SUCCESSFULL);
     }
     else
     {
         linkstatus_->setErrorOccurred(true);
         linkstatus_->setError(i18n( "Link destination not found." ));
+        linkstatus_->setStatus(LinkStatus::BROKEN);
     }
 
     finnish();
@@ -540,12 +622,14 @@ void LinkChecker::checkRef(LinkStatus const* linkstatus_parent)
 
     if(hasAnchor(html_part, linkStatus()->absoluteUrl().ref()))
     {
-        linkstatus_->setStatus("OK");
+        linkstatus_->setStatusText("OK");
+        linkstatus_->setStatus(LinkStatus::SUCCESSFULL);
     }
     else
     {
         linkstatus_->setErrorOccurred(true);
         linkstatus_->setError(i18n( "Link destination not found." ));
+        linkstatus_->setStatus(LinkStatus::BROKEN);
     }
 
     finnish();
@@ -579,4 +663,20 @@ void LinkChecker::killJob()
     aux->kill(true); // quietly   
 }
 
+LinkStatus::Status LinkChecker::getHttpStatus() const
+{
+    QString status_code = QString::number(linkstatus_->httpHeader().statusCode());
+    
+    if(status_code[0] == '2')
+        return LinkStatus::SUCCESSFULL;
+    else if(status_code[0] == '3')
+        return LinkStatus::HTTP_REDIRECTION;
+    else if(status_code[0] == '4')
+        return LinkStatus::HTTP_CLIENT_ERROR;
+    else if(status_code[0] == '5')
+        return LinkStatus::HTTP_SERVER_ERROR;
+    else
+        return LinkStatus::UNDETERMINED;
+}
+
 #include "linkchecker.moc"
