@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
 #include "node.h"
@@ -198,6 +198,26 @@ void NodeMETA::parseAttributeURL()
     }
 }
 
+QString NodeMETA::charset() const
+{
+    QString charset;
+    QString content(atributoCONTENT());
+    
+    if(content.isEmpty())
+        return charset;
+    
+    int index = content.find("charset=");
+    if(index != -1) 
+    {    
+        index += QString("charset=").length();
+        charset = content.mid(index, content.length() - index);
+        charset = charset.stripWhiteSpace();
+    }
+    
+//     kdDebug(23100) << "Charset: |" << charset << "|" << endl;
+    return charset;
+}
+
 /*
   NodeIMG________________________________________________________________________
 */
