@@ -177,6 +177,12 @@ inline NodeLINK::NodeLINK(QString const& content)
 
 // class NodeMeta________________________________________
 
+inline NodeMETA::NodeMETA()
+    : Node()
+{
+    element_ = META;
+}
+
 inline NodeMETA::NodeMETA(QString const& content)
         : Node(content)
 {
@@ -249,6 +255,7 @@ inline void NodeMETA::parseAttributeNAME()
 inline void NodeMETA::parseAttributeCONTENT()
 {
     attribute_content_ = getAttribute("CONTENT=");
+//     kdDebug(23100) << "CONTENT: " << attribute_content_ << endl;
 }
 
 
