@@ -48,7 +48,7 @@ QString ComboBox::currentState() const
 
 bool ComboBox::isKommanderWidget() const
 {
-  return TRUE;
+  return true;
 }
 
 QStringList ComboBox::associatedText() const
@@ -155,7 +155,7 @@ QString ComboBox::handleDCOP(int function, const QStringList& args)
       break;
     }
     default:
-      break;
+      return KommanderWidget::handleDCOP(function, args);
   }
   return QString::null;
 }
