@@ -26,11 +26,11 @@
 
 /* OTHER INCLUDES */
 #include <kommanderwidget.h>
-
+#include "kommander_export.h"
 class QWidget;
 
 class QShowEvent;
-class SpinBoxInt : public QSpinBox, public KommanderWidget
+class KOMMANDER_EXPORT SpinBoxInt : public QSpinBox, public KommanderWidget
 {
   Q_OBJECT
 
