@@ -42,7 +42,7 @@ TextBrowser::~TextBrowser()
 
 bool TextBrowser::isKommanderWidget() const
 {
-  return TRUE;
+  return true;
 }
 
 QStringList TextBrowser::associatedText() const
@@ -101,7 +101,7 @@ QString TextBrowser::handleDCOP(int function, const QStringList& args)
       clear();
       break;
     default:
-      break;
+      return KommanderWidget::handleDCOP(function, args);
   }
   return QString::null;
 }
