@@ -98,7 +98,7 @@ xslDbgShellSetOption(xmlChar * arg)
 			    optValue = !optValue;
 			if (optValue)
 			    enableNet = true;
-			result = TRUE;
+			result = true;
 			if (enableNet)
 			    xmlSetExternalEntityLoader(xsldbgDefaultEntLoader);
 			else
