@@ -36,7 +36,7 @@ QString QExtFileInfo::lastErrorMsg = "";
 
 QString QExtFileInfo::canonicalPath(const QString& path)
 {
-  if (!path.startsWith("/"))
+  if (!path.startsWith("/") || path == "/")
     return path;
   bool endsWithSlash = path.endsWith("/");
   QDir dir(path);
@@ -56,6 +56,11 @@ QString QExtFileInfo::canonicalPath(const QString& path)
   }
 }
 
+QString QExtFileInfo::homeDirPath()
+{
+  return QDir(QDir::homeDirPath()).canonicalPath();
+}
+
 /** create a relative short url based in baseURL*/
 KURL QExtFileInfo::toRelative(const KURL& _urlToConvert,const KURL& _baseURL)
 {
@@ -118,7 +123,7 @@ KURL QExtFileInfo::toAbsolute(const KURL& _urlToConvert,const KURL& _baseURL)
   KURL urlToConvert = _urlToConvert;
   KURL baseURL = _baseURL;
   KURL resultURL = urlToConvert;
-  
+
   if (urlToConvert.protocol() == baseURL.protocol() && !urlToConvert.path().startsWith("/"))
   {
     if (urlToConvert.isLocalFile())
@@ -200,7 +205,7 @@ bool QExtFileInfo::createDir(const KURL& path, QWidget *window)
     }
   //  dir2.setPath(dir2.path(-1));
     result = KIO::NetAccess::mkdir(dir2, window);
-    if (dir2.path() == "/")
+    if (dir2.path() == "/" || !result)
       break;
     i++;
   }
@@ -381,7 +386,7 @@ bool QExtFileInfo::internalExists(const KURL& url, bool readingOnly, QWidget *wi
   KIO::StatJob * job = KIO::stat(url2, false);
   job->setWindow(window);
   job->setDetails(0);
-  job->setSide(readingOnly); 
+  job->setSide(readingOnly);
   connect( job, SIGNAL( result (KIO::Job *) ),
            this, SLOT( slotResult (KIO::Job *) ) );
 
