@@ -17,15 +17,6 @@
 
 #include "debuggerui.h"
 
-#include "variableslistview.h"
-#include "debuggerbreakpointview.h"
-#include "debuggervariable.h"
-
-#include "quantacommon.h"
-#include "quanta.h"
-#include "resource.h"
-#include "whtmlpart.h"
-
 #include <kiconloader.h>
 #include <kdockwidget.h>
 #include <klocale.h>
@@ -33,6 +24,17 @@
 #include <qstring.h>
 #include <khtmlview.h>
 #include <kmditoolviewaccessor.h>
+#include <kstatusbar.h>
+
+#include "variableslistview.h"
+#include "debuggerbreakpointview.h"
+#include "backtracelistview.h"
+#include "debuggervariable.h"
+
+#include "quantacommon.h"
+#include "quanta.h"
+#include "resource.h"
+#include "whtmlpart.h"
 
 DebuggerUI::DebuggerUI(QObject *parent, const char *name)
     : QObject(parent, name), m_variablesListView(0)
@@ -50,13 +52,20 @@ DebuggerUI::DebuggerUI(QObject *parent, const char *name)
   m_debuggerBreakpointView->setCaption(i18n("Breakpoints"));
   m_debuggerBreakpointViewTVA = quantaApp->addToolWindow(m_debuggerBreakpointView, quantaApp->prevDockPosition(m_debuggerBreakpointView, KDockWidget::DockBottom), quantaApp->getMainDockWidget());
 
+  // Backtrace
+  m_backtraceListview = new BacktraceListview(quantaApp->getMainDockWidget(), "debuggerBacktrace");
+  m_backtraceListview->setIcon(SmallIcon("player_playlist"));
+  m_backtraceListview->setCaption(i18n("Backtrace"));
+  m_backtraceListviewTVA = quantaApp->addToolWindow(m_backtraceListview, quantaApp->prevDockPosition(m_backtraceListview, KDockWidget::DockBottom), quantaApp->getMainDockWidget());
+
   // Debug HTML preview
-  m_preview = new WHTMLPart(quantaApp, "debug_output");
+  m_preview = new WHTMLPart(quantaApp, "debug_output", true);
   //m_preview->view()->resize(0, 0);
   m_preview->view()->setIcon(UserIcon("debug_run"));
   m_preview->view()->setCaption(i18n("Debug Output"));
   m_previewTVA = quantaApp->addToolWindow(m_preview->view(), quantaApp->prevDockPosition(m_preview->view(), KDockWidget::DockBottom), quantaApp->getMainDockWidget());
-
+  connect(m_preview, SIGNAL(openFile(const KURL&, const QString&, bool)), quantaApp, SLOT(slotFileOpen(const KURL&, const QString&, bool)));
+  
   // Show debugger toolbar
   quantaApp->toolBar("debugger_toolbar")->show();
 
@@ -77,8 +86,14 @@ DebuggerUI::~DebuggerUI()
 
   // Remove breakpointlist
   quantaApp->deleteToolWindow(m_debuggerBreakpointViewTVA);
-  quantaApp->deleteToolWindow(m_previewTVA);
   m_debuggerBreakpointViewTVA = 0L;
+
+  // Remove backtrace
+  quantaApp->deleteToolWindow(m_backtraceListviewTVA);
+  m_backtraceListviewTVA = 0L;
+
+  // Remove output
+  quantaApp->deleteToolWindow(m_previewTVA);
   m_previewTVA = 0L;
 }
 
@@ -93,6 +108,10 @@ void DebuggerUI::showMenu()
   }
   else
     m_debuggerMenuID  = 0;
+
+  // Status indicator
+  quantaApp->statusBar()->insertFixedItem(i18n("Debugger Inactive"), IDS_STATUS_DEBUGGER);
+
 }
 
 void DebuggerUI::hideMenu()
@@ -104,12 +123,10 @@ void DebuggerUI::hideMenu()
     mb->removeItem(m_debuggerMenuID);
   }
   m_debuggerMenuID = 0;
-}
 
-void DebuggerUI::setVariables(const QPtrList<DebuggerVariable>& vars)
-{
-  m_variablesListView->clear();
-  m_variablesListView->setVariables(vars);
+  // Status indicator
+  quantaApp->statusBar()->removeItem(IDS_STATUS_DEBUGGER);
+
 }
 
 void DebuggerUI::addVariable(DebuggerVariable* var)
@@ -117,11 +134,6 @@ void DebuggerUI::addVariable(DebuggerVariable* var)
   m_variablesListView->addVariable(var);
 }
 
-void DebuggerUI::parsePHPVariables(const QString &varstring)
-{
-  m_variablesListView->parsePHPVariables(varstring);
-}
-
 void DebuggerUI::showBreakpoint(const DebuggerBreakpoint &bp)
 {
   m_debuggerBreakpointView->showBreakpoint(bp);
@@ -136,14 +148,58 @@ void DebuggerUI::sendRequest(const KURL &url)
   m_preview->openURL(url);
 }
 
-/*void DebuggerUI::preWatchUpdate()
+void DebuggerUI::slotStatus( DebuggerStatus status )
 {
-  m_variablesListView->preWatchUpdate();
+  switch(status)
+  {
+    case NoSession:
+      quantaApp->statusBar()->changeItem(i18n("No session"), IDS_STATUS_DEBUGGER);
+      break;
+
+    case AwaitingConnection:
+      quantaApp->statusBar()->changeItem(i18n("Waiting"), IDS_STATUS_DEBUGGER);
+      break;
+
+    case Connected:
+      quantaApp->statusBar()->changeItem(i18n("Connected"), IDS_STATUS_DEBUGGER);
+      break;
+
+    case Paused:
+      quantaApp->statusBar()->changeItem(i18n("Paused"), IDS_STATUS_DEBUGGER);
+      break;
+
+    case Running:
+      quantaApp->statusBar()->changeItem(i18n("Running"), IDS_STATUS_DEBUGGER);
+      break;
+
+    case Tracing:
+      quantaApp->statusBar()->changeItem(i18n("Tracing"), IDS_STATUS_DEBUGGER);
+      break;
+
+    case HaltedOnError:
+      quantaApp->statusBar()->changeItem(i18n("On error"), IDS_STATUS_DEBUGGER);
+      break;
+
+    case HaltedOnBreakpoint:
+      quantaApp->statusBar()->changeItem(i18n("On breakpoint"), IDS_STATUS_DEBUGGER);
+      break;
+
+    default:
+      quantaApp->statusBar()->changeItem("", IDS_STATUS_DEBUGGER);
+  }
 }
 
-void DebuggerUI::postWatchUpdate()
+void DebuggerUI::backtraceClear( )
 {
-  m_variablesListView->postWatchUpdate();
-}*/
+  if(m_backtraceListview)
+    m_backtraceListview->clear();
+}
+
+void DebuggerUI::backtraceShow( long level, BacktraceType type, const QString & filename, long line, const QString & func )
+{
+  if(m_backtraceListview)
+    m_backtraceListview->backtraceShow(level, type, filename, line, func);
+}
+
 
 #include "debuggerui.moc"
