@@ -17,9 +17,8 @@
 #ifndef QUANTADEBUGGERGUBED_H
 #define QUANTADEBUGGERGUBED_H
 
-#include <qserversocket.h>
-#include <qsocket.h>
-#include <kextsock.h>
+#include <kserversocket.h>
+#include <kstreamsocket.h>
 #include <qptrlist.h>
 #include <kurl.h>
 #include <qdom.h>
@@ -27,6 +26,7 @@
 #include "debuggerclient.h"
 
 typedef QValueList<QString> WatchList;
+typedef QMap<QString, QString> StringMap;
 
 class QuantaDebuggerGubed : public DebuggerClient
 {
@@ -40,8 +40,8 @@ class QuantaDebuggerGubed : public DebuggerClient
     enum State
     {
       Pause = 0,
-      RunDisplay,
-      RunNoDisplay
+      Trace,
+      Run
     };
     // Error codes
     enum Errors
@@ -61,8 +61,8 @@ class QuantaDebuggerGubed : public DebuggerClient
 
     // Execution control
     void request();
+    void trace();
     void run();
-    void leap();
     void skip();
     void stepInto();
     void stepOver();
@@ -88,7 +88,7 @@ class QuantaDebuggerGubed : public DebuggerClient
     // Breakpoints
     void addBreakpoint(DebuggerBreakpoint* breakpoint);
     void removeBreakpoint(DebuggerBreakpoint* breakpoint);
-    void showCondition(const QString &expression);
+    void showCondition(const StringMap &args);
 
     // Variables
     void addWatch(const QString &variable);
@@ -96,8 +96,8 @@ class QuantaDebuggerGubed : public DebuggerClient
     void variableSetValue(const DebuggerVariable &variable);
 
   private:
-    KExtendedSocket *m_socket;
-    KExtendedSocket *m_server;
+    KNetwork::KStreamSocket *m_socket;
+    KNetwork::KServerSocket *m_server;
     QString m_command, m_buffer;
     long    m_datalen;
 
@@ -114,27 +114,40 @@ class QuantaDebuggerGubed : public DebuggerClient
 
     WatchList m_watchlist;
 
-    bool sendCommand(const QString&, const QString&);
+//     bool sendCommand(const QString&, const QString&);
+    bool sendCommand(const QString& command, StringMap args);
+    bool sendCommand(const QString& command, char * firstarg, ...);
+
     void processCommand(const QString&);
     void sendWatches();
     void sendBreakpoints();
     void debuggingState(bool enable);
+    void connected();
 
     QString mapServerPathToLocal(const QString& serverpath);
     QString mapLocalPathToServer(const QString& localpath);
-    void showWatch(const QString& data);
     QString bpToGubed(DebuggerBreakpoint* breakpoint);
 
+    // Communication helpers
+    QString phpSerialize(StringMap args);
+    StringMap parseArgs(const QString &args);
+
+    // Variables
+    DebuggerVariable* parsePHPVariables(const QString &varstring);
+    DebuggerVariable* parsePHPVariables(QString &str);
+    void showWatch(const QString& data);
+
+    
   public slots:
     // Socket slots
-    void slotConnected();
-    void slotConnectionClosed(int state);
-    void slotError(int);
+    void slotConnected(const KNetwork::KResolverEntry &);
+    void slotConnectionClosed();
+    void slotError(int error);
     void slotReadyRead();
     void slotReadyAccept();
 
   signals:
-
+    void updateStatus(DebuggerUI::DebuggerStatus);
 };
 
 #endif
