@@ -69,6 +69,8 @@ DocTreeView::DocTreeView(QWidget *parent, const char *name )
 
 
 DocTreeView::~DocTreeView(){
+  contextHelpDict->setAutoDelete(true);
+  delete contextHelpDict;
 }
 
 void DocTreeView::slotRefreshTree()
